@@ -68,8 +68,7 @@ class PSD:
         print("Resolution mode: " + str(self.resolutionMode))
         print("Command object: " + str(self.command))
 
-    def isCommandValid(self, command: str):
-        result = False
+    def getTypeOfCommand(self, command: str):
         type = 0
         if len(command) > 0:
             if "h" in command:
@@ -91,22 +90,19 @@ class PSD:
                 print("basic command")
                 type = type | 0b0001
 
-        if type == 0b0010 or type == 0b0100 or type == 0b0001:
-            result = True
-
-        return result
+        return type
 
     def checkValidity(self, command: str):
         result: bool = False
         print("Check validity for command " + command)
 
-        if "cmdError" not in command and self.isCommandValid(command):
-            #if "g" in command or "G" in command:
-            result = self.checkGgPairs(self.command.command_g_counter, self.command.command_G_counter)
-            if result:
-                print("Valid command!")
-            else:
-                print("Error! Wrong parameter value for command! Check manual!")
+        if "cmdError" not in command:
+            commandType = self.getTypeOfCommand(command)
+            if (commandType == 0b0010 or commandType == 0b0100 or commandType == 0b0001) and \
+                    self.checkGgPairs(self.command.command_g_counter, self.command.command_G_counter):
+                result = True
+        else:
+            print("Error! Wrong command! Check manual!")
 
         return result
 
